# 16 Messier objects not included in other Celestia catalogs
# gathered by Selden Ball, 13 August 2003
# updated 27 Sep 2003 with better quality pictures
#
# The initial RA,Dec and Distance values were from SEDS articles
# See  http://www.seds.org/
#
# The RA, Dec and radius values specified here are those needed to place
# the images in the correct places. They are not the nominal locations
# of Messier's objects themselves.
# 
# Initial model orientation determined using 
# Grant Hutchison's DSC spreadsheet
#
# Many of the images were positioned by using background images
# downloaded from http://virtualsky.org/
#
# The collection of images provided with this catalog are 512x512 pixels, 
# high quality Jpegs. These 16 images require about 16MB of graphics memory.
#
# It is expected that fans of Messier's objects will obtain
# high resolution and accurately positioned models from other sources.
#
# the Crab nebula
Nebula "M1" 
{
	Mesh "m1.3ds" 
Axis   [-0.986386 -0.154404 0.0565825] Angle 92.728

	RA	5.575 
	Dec	22.024 
	Distance	6300
	Radius	8.6
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+1"
}

# Lagoon Nebula = NGC 6523
Nebula "M8" 
{
	Mesh "m8.3ds" 
Axis       [-0.0077 -0.7013 -0.7129]
Angle      179.658

	RA	18.0678 
	Dec	-24.353 
	Distance	5200
	Radius	31.5
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+8"
}

# Omega Nebula = NGC 6618
Nebula "M17" 
{
	Mesh "m17.3ds" 
Axis       [-0.0411 -0.7498 -0.6604]
Angle      177.787

	RA	18.346
	Dec	-16.175
	Distance	5000
	Radius	12
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+17"
}

# Triffid Nebula = NGC 6514
Nebula "M20" 
{
	Mesh "m20.3ds" 
Axis       [-0.0053 -0.7096 -0.7046]
Angle      179.759

	RA	18.04 
	Dec	-22.964 
	Distance	5200
	Radius	17.9
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+20"
}
Nebula "M24" 
{
	Mesh "m24.3ds" 
Axis      [-0.0589856 -0.736631 -0.673717] Angle 181.424

	RA	 18.287 
	Dec	-18.6
	Distance	10000
	Radius	110
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+24"
}

# Dumbbell Nebula = NGC 6853
Nebula "M27" 
{
	Mesh "m27.3ds" 
Axis      [0.807656 0.106713 -0.579917] Angle 48.03

	RA	19.9933
	Dec	22.725
	Distance	1250
	Radius	1.95
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+27"
}


# WNC 4 (Winnecke 4) double star
# HD 238107, HD 238108
Nebula "M40" 
{
	Mesh "m40.3ds" 
Axis       [-0.3882 0.9191 0.0681]
Angle      106.996

	RA	12.37086 
	Dec	58.085 
	Distance	510
	Radius 0.75
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+40"
}



# Orion Nebula = NGC 1976
Nebula "M42" 
{
	Mesh "m42.3ds" 
Axis       [-0.9981 -0.0504 -0.0366]
Angle      118.989

	RA	5.5827
	Dec	-5.485
	Distance	1177.5
	Radius	8.5
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+42"
}
# De Mairan's Nebula = NGC 1982
Nebula "M43" 
{
# a single image is used for both m42 and m43
	RA	5.5933
	Dec	-5.267
	Distance	1177.5
	Radius	4
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+43"
}

# Beehive Cluster = Praesepe
Nebula "M44" 
{
	Mesh "m44.3ds" 
Axis       [-0.8944 0.4109 0.1769]
Angle      99.810


	RA	8.669
	Dec	19.759
	Distance	577
	Radius	5.1
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+44"
}

# Pleiades
Nebula "M45" 
{
	Mesh "m45.3ds" 
Axis       [-0.9204 -0.3645 -0.1415]
Angle      94.074


	RA	3.77
	Dec	24.17
	Distance	380
	Radius	3.15
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+45"
}

# Ring Nebula = NGC 6720
Nebula "M57" 
{
	Mesh "m57.3ds" 
Axis       [-0.0761426 -0.954784 -0.287383] Angle 169.996

	RA   18.89275
	Dec  33.028 
	Distance	2300

	Radius 1.18
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+57"
}
# 4 star asterism = NGC 6994
#Star RA (2000.0) Dec (2000.0) V     B-V
#      h  m  s    deg  '  "
#-----------------------------------------
# 1   20:58:56.8  -12:38:29  10.355  1.002
# 2   20:58:57.8  -12:37:45  11.269  0.452
# 3   20:58:54.8  -12:38:04  11.675  0.575
# 5   20:58:53.5  -12:37:54  12.322  0.870
#
Nebula "M73" 
{
	Mesh "m73.3ds" 
Axis       [-0.3443 -0.7235 -0.5984]
Angle      160.133

	RA	20.9822	
	Dec	-12.634
	Distance	2000
	Radius 3 
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+73"
}




# Little Dumbbell Nebula = NGC 650
Nebula "M76" 
{
	Mesh "m76.3ds" 
Axis    [-0.615822 -0.784498 -0.0729808] Angle 90.5419

	RA	1.7045
	Dec	51.575
	Distance	3400
	Radius	6.15
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+76"
}



# Diffuse reflection Nebula in Orion = NGC 2068
Nebula "M78" 
{
	Mesh "m78.3ds" 
Axis       [-0.9994 -0.0290 -0.0190]
Angle      113.424

	RA	 5.779
	Dec	 0.13
	Distance	1600
	Radius	6.65
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+78"
}


# Owl Nebula = NGC 3587
Nebula "M97" 
{
	Mesh "m97.3ds" 
Axis     [-0.584259 -0.0637222 0.809062] Angle 45.1044

	RA	 11.24667
	Dec	55.01667
	Distance	2600
	Radius 	2.45
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+97"
}



# dubious; maybe NGC 5866
Nebula "M102"
{
	Mesh "m102.3ds" 
Axis        [-0.20726 0.975903 -0.0682352] Angle 229.072

	RA	15.10725
	Dec	55.760
	Distance	40000000
	Radius	34000
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+5866"
}
